diff --git a/src/password-store.sh b/src/password-store.sh
index 284eabf..a6e0b0f 100755
--- a/src/password-store.sh
+++ b/src/password-store.sh
@@ -408,10 +408,39 @@ cmd_show() {
 }
 
 cmd_find() {
-	[[ $# -eq 0 ]] && die "Usage: $PROGRAM $COMMAND pass-names..."
+	DEFAULT_PASS_NOTREE=0
+	local opts notree=0
+	opts="$($GETOPT -o n -l notree -n "$PROGRAM" -- "$@")"
+	local err=$?
+	eval set -- "$opts"
+	while true; do case $1 in
+		-n|--notree) notree="1"; shift ;;
+		--) shift; break ;;
+	esac done
+	[[ $# -ne 1 ]] && die "Usage: $PROGRAM $COMMAND [--notree,-n] pass-names..."
 	IFS="," eval 'echo "Search Terms: $*"'
 	local terms="*$(printf '%s*|*' "$@")"
+	local f
+	local c
+	tmpdir #Defines $SECURE_TMPDIR
+	local tmp_file=$(mktemp -u "$SECURE_TMPDIR/XXXXXX")
+
+	[[ -z "$PASS_NOTREE" ]] && PASS_NOTREE="$DEFAULT_PASS_NOTREE"
+	[[ "$PASS_NOTREE" -eq 1 ]] && notree=1
+
+	if [[ $notree -eq 0 ]]
+	then
 	tree -C -l --noreport -P "${terms%|*}" --prune --matchdirs --ignore-case "$PREFIX" | tail -n +2 | sed -E 's/\.gpg(\x1B\[[0-9]+m)?( ->|$)/\1\2/g'
+	else
+	  c=$(echo "$PREFIX" | wc -c)
+	  let c++
+	  find "$PREFIX" -follow -type d -iname "*${@}*" 2>/dev/null | while read f
+	  do
+	    find "$f" -follow -type f -iname '*.gpg' 2>/dev/null
+	  done > "$tmp_file"
+	  find "$PREFIX" -follow -type f -iname "*${@}*.gpg" 2>/dev/null >> "$tmp_file"
+	  sort -u "$tmp_file" | sed 's/.gpg//g' | cut -c $c- && rm -f "$tmp_file"
+	fi
 }
 
 cmd_grep() {
